@@ -45,6 +45,9 @@ $(document).ready(function() {
     // Handle user contributed ssi overwrites
     adagios.misc.ssi_overwrites();
 
+    // Handle user contributed ssi overwrites
+    adagios.misc.modal_resize();
+
 });
 
 
@@ -514,7 +517,7 @@ adagios.misc.init_tab_selection = function() {
     anchor = anchor.split('_tab')[0];
     var current_tab = tabs.find('a[href="#' + anchor + '"]');
     if (current_tab.length === 0) {
-        current_tab = tabs.find('a:first');
+        current_tab = tabs.find('a[data-toggle=tab]:first');
     }
     current_tab.tab('show');
 
@@ -606,7 +609,12 @@ adagios.status.update_row_color = function(checkbox) {
 // Acknowledge, downtime, etc.
 adagios.status.get_selected_objects = function() {
     var result = [];
-    var checked_boxes = $( ".selectable :checked" );
+    var primary = $( ".chkbox-primary:checked " );
+    var checked_boxes = $( ".selectable :checked:visible" );
+
+    if (checked_boxes.length == 0) {
+        checked_boxes = primary;
+    }
     checked_boxes.each(function() {
         result.push($(this).data());
     });
@@ -760,7 +768,8 @@ adagios.status.reschedule = function() {
 adagios.misc.turn_tables_into_datatables = function() {
     var oTable = $('.datatable').dataTable( {
         "bPaginate": true,
-        "iDisplayLength": 100
+        "iDisplayLength": 100,
+        "sPaginationType": "bootstrap",
     });
     $('.dataTables_length').hide();
 
@@ -919,4 +928,12 @@ adagios.misc.logout = function() {
         // return !!outcome
     })(/*if present URI does not return 200 OK for GET, set some other 200 OK location here*/)
 
-};
\ No newline at end of file
+};
+
+// Resize modals to relative size to window
+adagios.misc.modal_resize = function() {
+    $('div.modal').on('show', function() {
+        $(this).find('div.modal-body').css({'max-height': ($( window ).height() * 0.7)+"px" });
+        $(this).find('div.modal-body').css({'max-width': ($( window ).width() * 0.9)+"px" });
+    });
+};
