@@ -391,6 +391,50 @@ def mail(request):
         c['form'].save()
     return render_to_response('misc_mail.html', c, context_instance=RequestContext(request))
 
+def get_access_level(request):
+    """ Return the access level of current user.
+
+    Returns the following in order:
+        "administrator" - if user is an belongs to administrators group
+        "operator" - if user belongs to operators group
+        "auditor" - if user belongs to auditors group
+        "contact" - if user is defined as a contact
+        None - if user is not defined at all
+
+    """
+    user = request.META.get('REMOTE_USER', 'anonymous')
+    admins = adagios.settings.administrators.split(',')
+    operators = adagios.settings.operators.split(',')
+    auditors = adagios.settings.auditors.split(',')
+
+    if user in admins:
+        return "administrator"
+    if user in operators:
+        return "operator"
+    if user in auditors:
+        return "auditor"
+
+    # Check if this user has any contactgroups that grant him privileges
+    contactgroups = adagios.status.utils.get_contactgroups(
+        request,
+        'Columns: name',
+        'Filter: members >= %s' % user,
+    )
+    for group in contactgroups:
+        group_name = group['name']
+        if group_name in admins:
+            return "administrator"
+        if group_name in operators:
+            return "operator"
+        if group_name in auditors:
+            return "auditor"
+
+    # Check if this user is defined as a contact
+    contacts = adagios.status.utils.get_contacts(request, name=user)
+    if contacts:
+        return "contact"
+    return None
+
 
 @adagios_decorator
 def test(request):
@@ -401,6 +445,8 @@ def test(request):
     c.update(csrf(request))
     # Get some test data
 
+    print "you are: ", get_access_level(request)
+
     if request.method == 'POST':
         c['form'] = forms.PluginOutputForm(data=request.POST)
         if c['form'].is_valid():
@@ -411,43 +457,6 @@ def test(request):
     return render_to_response('test.html', c, context_instance=RequestContext(request))
 
 
-@adagios_decorator
-def edit_check_command(request):
-    """ Generic view for editing check command of a service
-    """
-    c = {}
-    c['messages'] = []
-    c['errors'] = []
-    c.update(csrf(request))
-
-    for i in 'host_name', 'service_description', 'check_command':
-        if i in request.GET:
-            c[i] = request.GET.get(i).split('!')[0]
-        else:
-            c['errors'].append("%s is required" % i)
-            return render_to_response('edit_check_command.html', c, context_instance=RequestContext(request))
-
-    hosts = pynag.Model.Host.objects.filter(host_name=c['host_name'])
-    if len(hosts) == 0:
-        c['errors'].append("Host %s was not found " % (c['host_name']))
-    services = pynag.Model.Service.objects.filter(
-        host_name=c['host_name'], service_description=c['service_description'])
-    if len(services) == 0:
-        c['errors'].append("Service %s/%s was not found " %
-                           (c['host_name'], c['service_description']))
-    command_names = map(
-        lambda x: x.get("command_name", ''), pynag.Model.Command.objects.all)
-    if c['check_command'] in (None, '', 'None'):
-        c['check_command'] = ''
-    elif c['check_command'] not in command_names:
-        c['errors'].append(
-            "Check Command %s was not found " % (c['check_command']))
-    c['command_names'] = command_names
-
-    # Overwrites from the browser
-    return render_to_response('edit_check_command.html', c, context_instance=RequestContext(request))
-
-
 @adagios_decorator
 def paste(request):
     """ Generic test view, use this as a sandbox if you like
