@@ -7,13 +7,13 @@ from django.utils import simplejson
 from django.views.decorators.csrf import csrf_exempt
 from django.template import RequestContext
 from django.core.urlresolvers import resolve
-
+from adagios.views import adagios_decorator
 
 import inspect
 from django import forms
 import os
 my_module = None
-
+import adagios.rest.urls
 
 def _load(module_path):
     #global my_module
@@ -23,6 +23,7 @@ def _load(module_path):
 
 
 @csrf_exempt
+@adagios_decorator
 def handle_request(request, module_name, module_path, attribute, format):
     m = _load(module_path)
     # TODO: Only allow function calls if method == POST
@@ -42,6 +43,7 @@ def handle_request(request, module_name, module_path, attribute, format):
             c['function_name'] = attribute
             c['form'] = CallFunctionForm(function=item, initial=request.GET)
             c['docstring'] = docstring
+            c['module_name'] = module_name
             if not request.GET.items():
                 return render_to_response('function_form.html', c, context_instance=RequestContext(request))
             # Handle get parameters
@@ -50,6 +52,11 @@ def handle_request(request, module_name, module_path, attribute, format):
                 # TODO: Is it safe to turn all digits to int ?
                 #if str(v).isdigit(): v = int(float(v))
                 arguments[k.encode('utf-8')] = v.encode('utf-8')
+            # Here is a special hack, if the method we are calling has an argument
+            # called "request" we will not let the remote user ship it in.
+            # instead we give it a django request object
+            if 'request' in inspect.getargspec(item)[0]:
+                arguments['request'] = request
             result = item(**arguments)
     elif request.method == 'POST':
         item = members[attribute]
@@ -66,7 +73,7 @@ def handle_request(request, module_name, module_path, attribute, format):
                 arguments['request'] = request
             result = item(**arguments)
     else:
-        raise BaseException("Unsupported operation: %s" % (request.method))
+        raise BaseException("Unsupported operation: %s" % (request.method, ))
     # Everything below is just about formatting the results
     if format == 'json':
         result = simplejson.dumps(
@@ -88,7 +95,19 @@ def handle_request(request, module_name, module_path, attribute, format):
     return HttpResponse(result, mimetype=mimetype)
 
 
+@adagios_decorator
+def list_modules(request):
+    """ List all available modules and their basic info
+
+    """
+    rest_modules = adagios.rest.urls.rest_modules
+    return render_to_response('list_modules.html', locals(), context_instance=RequestContext(request))
+
+
+@adagios_decorator
 def index(request, module_name, module_path):
+    """ This view is used to display the contents of a given python module
+    """
     m = _load(module_path)
     gets, puts = [], []
     blacklist = ('argv', 'environ', 'exit', 'path', 'putenv', 'getenv', )
