@@ -31,10 +31,19 @@ def services(request, fields=None, **kwargs):
     """
     return adagios.status.utils.get_services(request=request, fields=fields, **kwargs)
 
-def services_dt(fields=None, *args, **kwargs):
+def services_dt(request, fields=None, **kwargs):
     """ Similar to hosts(), is a wrapper around adagios.status.utils.get_services()
     """
-    return adagios.status.utils.get_services(fields=fields, *args, **kwargs)
+    services = adagios.status.utils.get_services(request=request, fields='host_name,description')
+
+    result = {
+        'sEcho': len(services),
+	'iTotalRecords': len(services),
+        'aaData': []
+    }
+    for service in services:
+        result['aaData'].append(service.values())
+    return result
 
 
 def contacts(request, fields=None, *args, **kwargs):
@@ -550,7 +559,7 @@ def command_line(host_name, service_description=None):
 def _get_host_or_service(host_name, service_description=None):
     """ Return a pynag.Model.Host or pynag.Model.Service or raise exception if none are found """
     host = pynag.Model.Host.objects.get_by_shortname(host_name)
-    if not service_description:
+    if not service_description or service_description == '_HOST_':
         return host
     else:
         search_result = pynag.Model.Service.objects.filter(host_name=host_name, service_description=service_description)
